@@ -2,14 +2,28 @@
 
 # local
 from .between import between
-from .btc_address import btc_address
 from .card import amex, card_number, diners, discover, jcb, mastercard, unionpay, visa
-from .country_code import country_code
+from .country import calling_code, country_code, currency
+from .cron import cron
+from .crypto_addresses import bsc_address, btc_address, eth_address, trx_address
 from .domain import domain
 from .email import email
-from .hashes import md5, sha1, sha224, sha256, sha512
+from .encoding import base16, base32, base58, base64
+from .finance import cusip, isin, sedol
+from .hashes import md5, sha1, sha224, sha256, sha384, sha512
 from .hostname import hostname
-from .i18n import es_cif, es_doi, es_nie, es_nif, fi_business_id, fi_ssn
+from .i18n import (
+    es_cif,
+    es_doi,
+    es_nie,
+    es_nif,
+    fi_business_id,
+    fi_ssn,
+    fr_department,
+    fr_ssn,
+    ind_aadhar,
+    ind_pan,
+)
 from .iban import iban
 from .ip_address import ipv4, ipv6
 from .length import length
@@ -19,14 +33,14 @@ from .url import url
 from .utils import ValidationError, validator
 from .uuid import uuid
 
-# from .crypto_addresses import eth_address
-
 __all__ = (
     # ...
     "between",
-    # crypto addresses
+    # crypto_addresses
+    "bsc_address",
     "btc_address",
-    # "eth_address",
+    "eth_address",
+    "trx_address",
     # cards
     "amex",
     "card_number",
@@ -36,17 +50,31 @@ __all__ = (
     "mastercard",
     "visa",
     "unionpay",
-    # ...
+    # country
+    "calling_code",
     "country_code",
+    "currency",
+    # ...
+    "cron",
     # ...
     "domain",
     # ...
     "email",
+    # encodings
+    "base16",
+    "base32",
+    "base58",
+    "base64",
+    # finance
+    "cusip",
+    "isin",
+    "sedol",
     # hashes
     "md5",
     "sha1",
     "sha224",
     "sha256",
+    "sha384",
     "sha512",
     # ...
     "hostname",
@@ -57,9 +85,13 @@ __all__ = (
     "es_nif",
     "fi_business_id",
     "fi_ssn",
+    "fr_department",
+    "fr_ssn",
+    "ind_aadhar",
+    "ind_pan",
     # ...
     "iban",
-    # ip addresses
+    # ip_addresses
     "ipv4",
     "ipv6",
     # ...
@@ -77,4 +109,4 @@ __all__ = (
     "validator",
 )
 
-__version__ = "0.22.0"
+__version__ = "0.34.0"
